@@ -28,7 +28,7 @@ def doReset():
     wf_job = group(addWFS.si(x) for x in chunk_dict(wfs,10000))
     spell_job = group(addSpells.si(x) for x in chunks(spells,10000))
     trans_job = group(addTrans.si(x) for x in chunks(trans,10000))
-    res = chain(loadCats.si(), lemma_job,wf_job,spell_job,trans_job,addRelationships.si(wfs))()
+    res = (loadCats.si() |lemma_job | wf_job | spell_job | trans_job | addRelationships.s(wfs))()
     res.get()
 
 
